@@ -1,6 +1,5 @@
 
 globi_api_url <- "api.globalbioticinteractions.org"
-globi_neo4j_url <- "neo4j.globalbioticinteractions.org"
 
 # Get GloBI Options
 
@@ -30,13 +29,6 @@ has_api <- function() {
   !is.null(curl::nslookup(globi_api_url, error = FALSE))
 }
 
-# Check If Neo4J API available
-#
-# @return true if neo4j api is resolvable, false otherwise
-has_neo4j_api <- function() {
-  !is.null(curl::nslookup(globi_neo4j_url, error = FALSE))
-}
-
 # Read csv URL
 # @param url points to csv resource
 read_csv_online <- function(url, ...) {
@@ -60,7 +52,7 @@ read_csv_online <- function(url, ...) {
 #' @return species interactions between source and target taxa
 #' @family interactions
 #' @export
-#' @examples \dontrun{
+#' @examples \donttest{
 #' get_interactions("Homo sapiens", "preysOn")
 #' get_interactions("Insecta", "parasiteOf")
 #' }
@@ -75,7 +67,7 @@ get_interactions <- function(taxon = "Homo sapiens", interaction.type = "preysOn
 #' @return species interactions given provided interaction type(s)
 #' @family interactions
 #' @export
-#' @examples \dontrun{
+#' @examples \donttest{
 #' get_interactions_by_type(interactiontype = c("eats", "eatenBy"))
 #' get_interactions_by_type(interactiontype = "parasiteOf")
 #' }
@@ -90,7 +82,7 @@ get_interactions_by_type <- function(interactiontype = c("interactsWith"), ...)
 #' @return list of recorded predator-prey interactions that involve the desired predator taxon
 #' @export
 #' @family interactions
-#' @examples \dontrun{
+#' @examples \donttest{
 #' get_prey_of("Homo sapiens")
 #' get_prey_of("Primates")
 #'}
@@ -105,7 +97,7 @@ get_prey_of <- function(taxon = "Homo sapiens", ...) {
 #' @return list of recorded prey-predator interactions that involve the desired prey taxon.
 #' @export
 #' @family interactions
-#' @examples \dontrun{
+#' @examples \donttest{
 #' get_predators_of("Rattus rattus")
 #' get_predators_of("Primates")
 #' }
@@ -113,54 +105,6 @@ get_predators_of <- function(taxon = "Rattus rattus", ...) {
   get_interactions(taxon, "preyedUponBy", ...)
 }
 
-cypher_result_as_dataframe <- function(result) {
-  nullToNA <- function(x) {
-    ifelse(is.null(x), NA, x)
-  }
-  f <- function(accum, x) {
-	  row <- data.frame(lapply(x, nullToNA), stringsAsFactors=FALSE)
-	  # give rows temporary and consist names for easy of combining
-    names(row) <- 1:length(x)
-    rbind(accum, row)
-  }
-  df <- Reduce(f, result$data, init=data.frame())
-  if (length(df) > 0) {
-    names(df) <- result$columns
-  }
-  df
-}
-
-#' Executes a Cypher Query Against GloBI's Neo4j Instance
-#'
-#' @import RCurl
-#' @param cypherQuery Cypher query (see http://github.com/globalbioticinteractions/globalbioticinteractions/wiki/cypher for examples)
-#' @param opts list of named options to configure GloBI API
-#' @return result of cypher query string
-#' @export
-query <- function(cypherQuery, opts = list()) {
-  if (has_neo4j_api()) {
-    h <- RCurl::basicTextGatherer()
-    opts_cypher <- add_missing_options(opts, host = globi_neo4j_url)
-    RCurl::curlPerform(
-      url=get_globi_url("/db/data/cypher", opts_cypher),
-      postfields=rjson::toJSON(list('query' = cypherQuery)),
-                httpheader=c(Accept="application/json",
-                           'Content-Type' = "application/json"),
-		writefunction = h$update,
-		verbose = FALSE
-    )
-    result <- rjson::fromJSON(h$value())
-    if (is.null(result$message)) {
-      cypher_result_as_dataframe(result)
-    } else {
-      stop(result$message)
-    }
-  } else {
-    stop(paste("GloBI Neo4j data services not available at [", globi_neo4j_url, "]. Are you connected to the internet?", sep = ""))
-  }
-}
-
-
 create_bbox_param <- function(bbox) {
   if (is.null(bbox)){
     "bbox="
@@ -205,7 +149,7 @@ create_bbox_param <- function(bbox) {
 #' @export
 #' @note For data sources in which type of interactions were not specified, the interaction is labeled "interacts_with"
 #' @family interactions
-#' @examples \dontrun{
+#' @examples \donttest{
 #' get_interactions_by_taxa(sourcetaxon = "Rattus")
 #' get_interactions_by_taxa(sourcetaxon = "Aves", targettaxon = "Rattus")
 #' get_interactions_by_taxa(sourcetaxon = "Rattus rattus",
@@ -213,7 +157,7 @@ create_bbox_param <- function(bbox) {
 #' }
 get_interactions_by_taxa <- function(sourcetaxon, targettaxon = NULL, interactiontype = NULL, accordingto = NULL,
   showfield = c("source_taxon_external_id","source_taxon_name","source_taxon_path","source_specimen_life_stage","interaction_type","target_taxon_external_id","target_taxon_name","target_taxon_path","target_specimen_life_stage","latitude","longitude","study_citation","study_external_id","study_source_citation"),
-  otherkeys = NULL, bbox = NULL, returnobservations = F, opts = list(), read_csv = read_csv_online){
+  otherkeys = NULL, bbox = NULL, returnobservations = FALSE, opts = list(), read_csv = read_csv_online){
   if(length(interactiontype)>0){
     interactiontypes <- as.vector(get_interaction_types(read_csv = read_csv)[,1])
     if(length(intersect(interactiontypes, interactiontype)) == 0){
@@ -278,7 +222,7 @@ get_interactions_by_taxa <- function(sourcetaxon, targettaxon = NULL, interactio
 #' @keywords database
 #' @export
 #' @family areas
-#' @examples \dontrun{
+#' @examples \donttest{
 #' get_interactions_in_area(bbox = c(-67.87, 12.79, -57.08, 23.32))
 #' }
 get_interactions_in_area <- function(bbox, ...){
@@ -302,7 +246,7 @@ get_interactions_in_area <- function(bbox, ...){
 #' @keywords database
 #' @export
 #' @family areas
-#' @examples \dontrun{
+#' @examples \donttest{
 #' get_interaction_areas ()
 #' get_interaction_areas (bbox=c(-67.87,12.79,-57.08,23.32))
 #' }
@@ -336,7 +280,7 @@ get_interaction_areas <- function(bbox = NULL, read_csv = read_csv_online, ...){
 #' @keywords database
 #' @export
 #' @family interactions
-#' @examples \dontrun{
+#' @examples \donttest{
 #' get_interaction_types()
 #' }
 get_interaction_types <- function(opts = list(), read_csv = read_csv_online) {
@@ -353,7 +297,7 @@ get_interaction_types <- function(opts = list(), read_csv = read_csv_online) {
 #' @keywords database
 #' @export
 #' @family data
-#' @examples \dontrun{
+#' @examples \donttest{
 #' get_data_fields()
 #' }
 get_data_fields <- function(opts = list(), read_csv = read_csv_online) {
@@ -425,70 +369,13 @@ unique_target_taxa_of_source_taxon <- function(source.taxon.name, target.taxon.n
 #' @return matrix representing species interactions between source and target taxa
 #' @family interactions
 #' @export
-#' @examples \dontrun{
+#' @examples \donttest{
 #' get_interaction_matrix("Homo sapiens", "Mammalia", "interactsWith")
 #' }
 get_interaction_matrix <- function(source.taxon.names = list('Homo sapiens'), target.taxon.names = list('Mammalia'), interaction.type = 'eats', opts = list(), read_csv = read_csv_online) {
   Reduce(function(accum, source.taxon.name) rbind(accum, unique_target_taxa_of_source_taxon(source.taxon.name, target.taxon.names, interaction.type, opts = opts, read_csv = read_csv)), source.taxon.names, init=data.frame())
 }
 
-#' Returns all known child taxa with known interaction of specified taxa and rank.
-#'
-#' @param taxon.names list of taxa of which child taxa should be included.
-#' @param rank selected taxonomic rank of child taxa
-#' @param skip number of child taxon names to skip before returning result. May be used for pagination.
-#' @param limit maximum number of child taxon names returned
-#' @param opts list of options including web service configuration like "port" and "host"
-#' @return list of child taxon names
-#' @family interactions
-#' @export
-#' @examples \dontrun{
-#' get_child_taxa(list("Aves"))
-#' }
-get_child_taxa <- function(taxon.names, rank = 'Species', skip = 0, limit = 25, opts = list()) {
-  luceneQuery <- paste('path:', taxon.names, ' ', sep='', collapse='')
-  cypher <- paste("START taxon = node:taxonPaths('", luceneQuery , "') WHERE has(taxon.rank) AND taxon.rank = '", rank, "' RETURN distinct(taxon.name) as `taxon.name` SKIP ", skip, " LIMIT ", limit, sep="")
-  query(cypher, opts = opts)$taxon.name
-}
-
 interaction_id_for_type <- function(interaction.type) {
   list(preysOn = 'RO_0002439', parasiteOf = 'RO_0002444', pollinates = 'RO_0002455')[[interaction.type]]
 }
-
-
-#' Returns all known child taxa with known interaction of specified source and target taxa on any rank.
-#'
-#' @param source.taxon.names list of taxon names for source
-#' @param target.taxon.names list of taxon names for target
-#' @param interaction.type kind of interaction
-#' @param skip number of records skipped before including record in result table, used in pagination
-#' @param limit maximum number of interaction to include
-#' @param opts connection parameters and other options
-#' @return table of matching source, target and interaction types
-#' @family interactions
-#' @export
-#' @examples \dontrun{
-#' get_interaction_table(source.taxon.names = list("Aves"), target.taxon.names = list('Insecta'))
-#' }
-get_interaction_table <- function(source.taxon.names = list(), target.taxon.names = list(), interaction.type = "preysOn", skip = 0, limit = 100, opts = list()) {
-  interaction.id <- interaction_id_for_type(interaction.type)
-  rel_type <- rel_type_interaction_type(interaction.type)
-
-  start_clause = list()
-  if (length(source.taxon.names) > 0) {
-    sourceLuceneQuery <- paste('path:\\\"', source.taxon.names, '\\\" ', sep='', collapse='')
-    start_clause <- list(paste('taxon = node:taxonPaths(\"', sourceLuceneQuery, '\")', sep=''))
-  }
-  if (length(target.taxon.names) > 0) {
-    targetLuceneQuery <- paste('path:\\\"', target.taxon.names, '\\\" ', sep='', collapse='')
-    start_clause <- list(start_clause, paste('preyTaxon = node:taxonPaths(\"', targetLuceneQuery, '\")', sep=''))
-  }
-  if (length(start_clause) == 0) {
-    stop('must define source or target taxa or both')
-  }
-  start_clause <- paste('START', paste(unlist(start_clause), collapse=','))
-  match_clause <- paste(' MATCH sameTaxon2<-[:SAME_AS]-taxon<-[:CLASSIFIED_AS]-specimen-[:', rel_type, ']->prey-[:CLASSIFIED_AS]->preyTaxon-[:SAME_AS]->sameTaxon', sep='')
-  where_clause <- ' WHERE sameTaxon.externalId =~ \"OTT.*\" AND sameTaxon2.externalId =~ \"OTT.*\"'
-  cypher <- paste(start_clause, match_clause, where_clause, ' RETURN id(specimen) as `source_specimen_id`, taxon.name as `source_name`, sameTaxon2.externalId as `source_id`, \"', interaction.type, '\" as `interaction_name`, \"', interaction.id, '\" as `interaction_id`, id(prey) as `target_specimen_id`, preyTaxon.name as `target_name`, sameTaxon.externalId as `target_id` SKIP ', skip, ' LIMIT ', limit, sep='')
-  query(cypher, opts = opts)
-}
